Module instance

Module instance 

Instance transformation data for GPU rendering.

Per-instance data like position, rotation, and scale is stored as GPU buffers and passed to shaders for efficient multi-draw instancing.

Structs

Instance
Per-instance transformation: position, rotation (as quaternion), and scale.
InstanceRaw
The raw instance is the actual data stored on the GPU