pub enum Out<S, E>where
E: Send,{
FutEvent(Vec<Box<dyn Future<Output = E> + Send>>),
FutFn(Vec<Box<dyn Future<Output = Box<dyn FnOnce(&mut S)>>>>),
Configure(Box<dyn FnOnce(&mut Context)>),
Composed(Vec<Out<S, E>>),
Empty,
}Expand description
This is the Output Type for every lifecycle hook where the user can pass async events that are handled according to the platform you’re running on.
Out::FutEvent can be used to resolve a future of an Event that is put in the Event Queue after
being resolved. The caller is responsible for handling the event later on and it will have no
side effects unless handled.
Out::FutFn can be used to directly modify the state and the mutation is handled internally with
no further action required by the callee but is blocking on non-wasn environments.
Out::Configure can be used to modify the Context during runtime for instance to change the tick
speed or the clear colour.
Empty is the default output used when no eventing/futures need to be handled.
Variants
FutEvent(Vec<Box<dyn Future<Output = E> + Send>>)
FutFn(Vec<Box<dyn Future<Output = Box<dyn FnOnce(&mut S)>>>>)
Configure(Box<dyn FnOnce(&mut Context)>)
Composed(Vec<Out<S, E>>)
Empty