pub struct AccelerationStructureBuildSizes {
pub acceleration_structure_size: u64,
pub update_scratch_size: u64,
pub build_scratch_size: u64,
}Expand description
Information of the required size for a corresponding entries struct (+ flags)
Fields
acceleration_structure_size: u64update_scratch_size: u64build_scratch_size: u64Trait Implementations
Sourceimpl Clone for AccelerationStructureBuildSizes
impl Clone for AccelerationStructureBuildSizes
Sourcefn clone(&self) -> AccelerationStructureBuildSizes
fn clone(&self) -> AccelerationStructureBuildSizes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for AccelerationStructureBuildSizes
impl Default for AccelerationStructureBuildSizes
Sourcefn default() -> AccelerationStructureBuildSizes
fn default() -> AccelerationStructureBuildSizes
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AccelerationStructureBuildSizes
impl PartialEq for AccelerationStructureBuildSizes
Sourcefn eq(&self, other: &AccelerationStructureBuildSizes) -> bool
fn eq(&self, other: &AccelerationStructureBuildSizes) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for AccelerationStructureBuildSizes
impl Eq for AccelerationStructureBuildSizes
impl StructuralPartialEq for AccelerationStructureBuildSizes