pub struct AttachmentOps(/* private fields */);Expand description
Attachment load and store operations.
There must be at least one flag from the LOAD group and one from the STORE group set.
Implementations
Sourceimpl AttachmentOps
impl AttachmentOps
Sourcepub const LOAD: AttachmentOps
pub const LOAD: AttachmentOps
Load the existing contents of the attachment.
Sourcepub const LOAD_CLEAR: AttachmentOps
pub const LOAD_CLEAR: AttachmentOps
Clear the attachment to a specified value.
Sourcepub const LOAD_DONT_CARE: AttachmentOps
pub const LOAD_DONT_CARE: AttachmentOps
The contents of the attachment are undefined.
Sourcepub const STORE: AttachmentOps
pub const STORE: AttachmentOps
Store the contents of the attachment.
Sourcepub const STORE_DISCARD: AttachmentOps
pub const STORE_DISCARD: AttachmentOps
The contents of the attachment are undefined after the pass.
Sourceimpl AttachmentOps
impl AttachmentOps
Sourcepub const fn empty() -> AttachmentOps
pub const fn empty() -> AttachmentOps
Get a flags value with all bits unset.
Sourcepub const fn all() -> AttachmentOps
pub const fn all() -> AttachmentOps
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<AttachmentOps>
pub const fn from_bits(bits: u8) -> Option<AttachmentOps>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> AttachmentOps
pub const fn from_bits_truncate(bits: u8) -> AttachmentOps
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> AttachmentOps
pub const fn from_bits_retain(bits: u8) -> AttachmentOps
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AttachmentOps>
pub fn from_name(name: &str) -> Option<AttachmentOps>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AttachmentOps) -> bool
pub const fn intersects(&self, other: AttachmentOps) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AttachmentOps) -> bool
pub const fn contains(&self, other: AttachmentOps) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AttachmentOps)
pub fn insert(&mut self, other: AttachmentOps)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AttachmentOps)
pub fn remove(&mut self, other: AttachmentOps)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AttachmentOps)
pub fn toggle(&mut self, other: AttachmentOps)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AttachmentOps, value: bool)
pub fn set(&mut self, other: AttachmentOps, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AttachmentOps) -> AttachmentOps
pub const fn intersection(self, other: AttachmentOps) -> AttachmentOps
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AttachmentOps) -> AttachmentOps
pub const fn union(self, other: AttachmentOps) -> AttachmentOps
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AttachmentOps) -> AttachmentOps
pub const fn difference(self, other: AttachmentOps) -> AttachmentOps
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: AttachmentOps) -> AttachmentOps
pub const fn symmetric_difference(self, other: AttachmentOps) -> AttachmentOps
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AttachmentOps
pub const fn complement(self) -> AttachmentOps
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AttachmentOps
impl AttachmentOps
Sourcepub const fn iter(&self) -> Iter<AttachmentOps>
pub const fn iter(&self) -> Iter<AttachmentOps>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AttachmentOps>
pub const fn iter_names(&self) -> IterNames<AttachmentOps>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.