pub struct MemoryFlags(/* private fields */);Implementations
Sourceimpl MemoryFlags
impl MemoryFlags
pub const TRANSIENT: MemoryFlags
pub const PREFER_COHERENT: MemoryFlags
Sourceimpl MemoryFlags
impl MemoryFlags
Sourcepub const fn empty() -> MemoryFlags
pub const fn empty() -> MemoryFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> MemoryFlags
pub const fn all() -> MemoryFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MemoryFlags>
pub const fn from_bits(bits: u32) -> Option<MemoryFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MemoryFlags
pub const fn from_bits_truncate(bits: u32) -> MemoryFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MemoryFlags
pub const fn from_bits_retain(bits: u32) -> MemoryFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MemoryFlags>
pub fn from_name(name: &str) -> Option<MemoryFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MemoryFlags) -> bool
pub const fn intersects(&self, other: MemoryFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: MemoryFlags) -> bool
pub const fn contains(&self, other: MemoryFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: MemoryFlags)
pub fn insert(&mut self, other: MemoryFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: MemoryFlags)
pub fn remove(&mut self, other: MemoryFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MemoryFlags)
pub fn toggle(&mut self, other: MemoryFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: MemoryFlags, value: bool)
pub fn set(&mut self, other: MemoryFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MemoryFlags) -> MemoryFlags
pub const fn intersection(self, other: MemoryFlags) -> MemoryFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: MemoryFlags) -> MemoryFlags
pub const fn union(self, other: MemoryFlags) -> MemoryFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: MemoryFlags) -> MemoryFlags
pub const fn difference(self, other: MemoryFlags) -> MemoryFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MemoryFlags) -> MemoryFlags
pub const fn symmetric_difference(self, other: MemoryFlags) -> MemoryFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> MemoryFlags
pub const fn complement(self) -> MemoryFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MemoryFlags
impl MemoryFlags
Sourcepub const fn iter(&self) -> Iter<MemoryFlags>
pub const fn iter(&self) -> Iter<MemoryFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MemoryFlags>
pub const fn iter_names(&self) -> IterNames<MemoryFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.