pub struct Buffer { /* private fields */ }Implementations
Sourceimpl Buffer
impl Buffer
Sourcepub unsafe fn from_raw(vk_buffer: Buffer) -> Buffer
pub unsafe fn from_raw(vk_buffer: Buffer) -> Buffer
Safety
vk_buffer’s memory must be managed by the caller- Externally imported buffers can’t be mapped by
wgpu
Sourcepub unsafe fn from_raw_managed(
vk_buffer: Buffer,
memory: DeviceMemory,
offset: u64,
size: u64,
) -> Buffer
pub unsafe fn from_raw_managed( vk_buffer: Buffer, memory: DeviceMemory, offset: u64, size: u64, ) -> Buffer
Safety
- We will use this buffer and the buffer’s backing memory range as if we have exclusive ownership over it, until the wgpu resource is dropped and the wgpu-hal object is cleaned up
- Externally imported buffers can’t be mapped by
wgpu offsetandsizemust be valid with the allocation ofmemory