Module render

Module render 

Render composition and pipeline batching.

This module defines the Render enum, which is used by scene nodes to specify how they should be rendered. The engine uses Render to sort objects into batches for different pipelines (basic, transparent, GUI, terrain, picking, etc.) and to support custom per-object render passes.

Key types

  • Render<'a, 'pass> is the primary enum describing render operations
  • Instanced<'a> contains data for instanced rendering (model + instance buffer)
  • Flat<'a> contains data for flat (2D / GUI) rendering (vertex + index buffers)

Structs

Flat
Data for flat (2D / GUI) object rendering: vertex and index buffers with a bind group.
Geometry
Data for custom instanced vertex rendering.
Instanced
Data for instanced object rendering: a model, instance buffer, and pick ID.

Enums

Render
Specifies how a scene object should be rendered.