Animation

Struct Animation 

pub struct Animation { /* private fields */ }

Implementations

Source

impl<'a> Animation

pub fn new(speed: f32, rep_after_sec: f32) -> Self

pub fn set_rep_time(&mut self, new_time: f32)

pub fn animate( &mut self, graph: &'a mut Box<dyn SceneNode>, anim_idx: usize, instance_idx: usize, )

This function checks whether the passed Scene Graph contains animation data and plays it according to the time passed since this Animation struct was initialized.

Repeats the animation after 20s (TODO: make this a parameter)

TODO: interpolate similar to animate_with(...args)

pub fn animate_with( &mut self, graph: &'a mut Box<dyn SceneNode>, current: &[&[usize]], reference: &[&Instance], idx: usize, dt: Duration, ) -> bool

This function animates a single frame with interpolation between the current position of the screne_graph and the position given in the animation List.

graph is the Scene Graph of the object to model current is a mapping between Scene Graph nodes and the passed animation positions reference is the desired position idx is the index of the instance to animate dt the duration since the last rendered frame