BindGroupLayoutEntry

Struct BindGroupLayoutEntry 

pub struct BindGroupLayoutEntry {
    pub binding: u32,
    pub visibility: ShaderStages,
    pub ty: BindingType,
    pub count: Option<NonZero<u32>>,
}
Describes a single binding inside a bind group.

Corresponds to WebGPU GPUBindGroupLayoutEntry.

Fields

binding: u32

Binding index. Must match shader index and be unique inside a BindGroupLayout. A binding of index 1, would be described as @group(0) @binding(1) in shaders.

visibility: ShaderStages

Which shader stages can see this binding.

ty: BindingType

The type of the binding

count: Option<NonZero<u32>>

If the binding is an array of multiple resources. Corresponds to binding_array<T> in the shader.

When this is Some the following validation applies:

  • Size must be of value 1 or greater.
  • When ty == BindingType::Texture, [Features::TEXTURE_BINDING_ARRAY] must be supported.
  • When ty == BindingType::Sampler, [Features::TEXTURE_BINDING_ARRAY] must be supported.
  • When ty == BindingType::Buffer, [Features::BUFFER_BINDING_ARRAY] must be supported.
  • When ty == BindingType::Buffer and ty.ty == BufferBindingType::Storage, [Features::STORAGE_RESOURCE_BINDING_ARRAY] must be supported.
  • When ty == BindingType::StorageTexture, [Features::STORAGE_RESOURCE_BINDING_ARRAY] must be supported.
  • When any binding in the group is an array, no BindingType::Buffer in the group may have has_dynamic_offset == true
  • When any binding in the group is an array, no BindingType::Buffer in the group may have ty.ty == BufferBindingType::Uniform.