StencilState

Struct StencilState 

#[repr(C)]
pub struct StencilState { pub front: StencilFaceState, pub back: StencilFaceState, pub read_mask: u32, pub write_mask: u32, }
State of the stencil operation (fixed-pipeline stage).

For use in DepthStencilState.

Corresponds to a portion of WebGPU GPUDepthStencilState.

Fields

front: StencilFaceState

Front face mode.

back: StencilFaceState

Back face mode.

read_mask: u32

Stencil values are AND’d with this mask when reading and writing from the stencil buffer. Only low 8 bits are used.

write_mask: u32

Stencil values are AND’d with this mask when writing to the stencil buffer. Only low 8 bits are used.

Implementations

Source

impl StencilState

pub fn is_enabled(&self) -> bool

Returns true if the stencil test is enabled.

pub fn is_read_only(&self, cull_mode: Option<Face>) -> bool

Returns true if the state doesn’t mutate the target values.

pub fn needs_ref_value(&self) -> bool

Returns true if the stencil state uses the reference value for testing.