#[non_exhaustive]pub enum EncoderStateError {
Invalid,
Ended,
Locked,
Unlocked,
Submitted,
}Expand description
Errors related to the state of a command or pass encoder.
The exact behavior of these errors may change based on the resolution of https://github.com/gpuweb/gpuweb/issues/5207.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Invalid
Used internally by wgpu functions to indicate the encoder already contained an error. This variant should usually not be seen by users of the API, since an effort should be made to provide the caller with a more specific reason for the encoder being invalid.
Ended
Returned immediately when an attempt is made to encode a command using an encoder that has already finished.
Locked
Returned by a subsequent call to encoder.finish(), if there was an
attempt to open a second pass on the encoder while it was locked for
a first pass (i.e. the first pass was still open).
Note: only command encoders can be locked (not pass encoders).
Unlocked
Returned when attempting to end a pass if the parent encoder is not locked. This can only happen if pass begin/end calls are mismatched.
Submitted
The command buffer has already been submitted.
Although command encoders and command buffers are distinct WebGPU
objects, we use CommandEncoderStatus for both.