pub struct CommandBuffer { /* private fields */ }Expand description
A buffer of commands to be submitted to the GPU for execution.
Once a command buffer is submitted to the queue, its contents are taken
to construct a [BakedCommands], whose contents eventually become the
property of the submission queue.
Implementations
Sourceimpl CommandBuffer
impl CommandBuffer
pub fn take_finished(&self) -> Result<CommandBufferMutable, CommandEncoderError>