ComputePass

Struct ComputePass 

pub struct ComputePass { /* private fields */ }
A pass’s encoder state and its validity are two distinct conditions, i.e., the full matrix of (open, ended) x (valid, invalid) is possible.

The presence or absence of the parent Option indicates the pass’s state. The presence or absence of an error in base.error indicates the pass’s validity.

Implementations

Source

impl ComputePass

pub fn label(&self) -> Option<&str>