#[repr(C)]pub struct RenderPassColorAttachment<TV = Id<TextureView>> {
pub view: TV,
pub depth_slice: Option<u32>,
pub resolve_target: Option<TV>,
pub load_op: LoadOp<Color>,
pub store_op: StoreOp,
}Expand description
Describes a color attachment to a render pass.
Fields
view: TVThe view to use as an attachment.
depth_slice: Option<u32>The depth slice index of a 3D view. It must not be provided if the view is not 3D.
resolve_target: Option<TV>The view that will receive the resolved output if multisampling is used.
load_op: LoadOp<Color>Operation to perform to the output attachment at the start of a renderpass.
This must be clear if it is the first renderpass rendering to a swap chain image.
store_op: StoreOpOperation to perform to the output attachment at the end of a renderpass.