pub struct RenderPassDescriptor<'a> {
pub label: Option<Cow<'a, str>>,
pub color_attachments: Cow<'a, [Option<RenderPassColorAttachment>]>,
pub depth_stencil_attachment: Option<&'a RenderPassDepthStencilAttachment<Id<TextureView>>>,
pub timestamp_writes: Option<&'a PassTimestampWrites>,
pub occlusion_query_set: Option<Id<QuerySet>>,
pub multiview_mask: Option<NonZero<u32>>,
}Expand description
Describes the attachments of a render pass.
Fields
label: Option<Cow<'a, str>>color_attachments: Cow<'a, [Option<RenderPassColorAttachment>]>The color attachments of the render pass.
depth_stencil_attachment: Option<&'a RenderPassDepthStencilAttachment<Id<TextureView>>>The depth and stencil attachment of the render pass, if any.
timestamp_writes: Option<&'a PassTimestampWrites>Defines where and when timestamp values will be written for this pass.
occlusion_query_set: Option<Id<QuerySet>>Defines where the occlusion query results will be stored for this pass.
multiview_mask: Option<NonZero<u32>>The multiview array layers that will be used