pub enum TempResource {
StagingBuffer(FlushedStagingBuffer),
ScratchBuffer(ScratchBuffer),
DestroyedBuffer(DestroyedBuffer),
DestroyedTexture(DestroyedTexture),
}Expand description
A texture or buffer to be freed soon.
This is just a tagged raw texture or buffer, generally about to be added to some other more specific container like:
-
PendingWrites::temp_resources: resources used by queue writes and unmaps, waiting to be folded in with the next queue submission -
ActiveSubmission::temp_resources: temporary resources used by a queue submission, to be freed when it completes
Variants
StagingBuffer(FlushedStagingBuffer)
ScratchBuffer(ScratchBuffer)
DestroyedBuffer(DestroyedBuffer)
DestroyedTexture(DestroyedTexture)