pub enum PollStatus {
QueueEmpty,
WaitSucceeded,
Poll,
}Expand description
Status of device poll operation.
Variants
QueueEmpty
There are no active submissions in flight as of the beginning of the poll call. Other submissions may have been queued on other threads during the call.
This implies that the given Wait was satisfied before the timeout.
WaitSucceeded
The requested Wait was satisfied before the timeout.
Poll
This was a poll.
Implementations
Sourceimpl PollStatus
impl PollStatus
Sourcepub fn is_queue_empty(&self) -> bool
pub fn is_queue_empty(&self) -> bool
Returns true if the result is Self::QueueEmpty.
Sourcepub fn wait_finished(&self) -> bool
pub fn wait_finished(&self) -> bool
Returns true if the result is either Self::WaitSucceeded or Self::QueueEmpty.