MemoryBudgetThresholds

Struct MemoryBudgetThresholds 

pub struct MemoryBudgetThresholds {
    pub for_resource_creation: Option<u8>,
    pub for_device_loss: Option<u8>,
}
Memory budget thresholds used by backends to try to avoid high memory pressure situations.

Currently only the D3D12 and (optionally) Vulkan backends support these options.

Fields

for_resource_creation: Option<u8>

Threshold at which texture, buffer, query set and acceleration structure creation will start to return OOM errors. This is a percent of the memory budget reported by native APIs.

If not specified, resource creation might still return OOM errors.

for_device_loss: Option<u8>

Threshold at which devices will become lost due to memory pressure. This is a percent of the memory budget reported by native APIs.

If not specified, devices might still become lost due to memory pressure.