DeviceDescriptor

Struct DeviceDescriptor 

pub struct DeviceDescriptor<L> {
    pub label: L,
    pub required_features: Features,
    pub required_limits: Limits,
    pub experimental_features: ExperimentalFeatures,
    pub memory_hints: MemoryHints,
    pub trace: Trace,
}
Describes a Device.

Corresponds to WebGPU GPUDeviceDescriptor.

Fields

label: L

Debug label for the device.

required_features: Features

Specifies the features that are required by the device request. The request will fail if the adapter cannot provide these features.

Exactly the specified set of features, and no more or less, will be allowed in validation of API calls on the resulting device.

required_limits: Limits

Specifies the limits that are required by the device request. The request will fail if the adapter cannot provide these limits.

Exactly the specified limits, and no better or worse, will be allowed in validation of API calls on the resulting device.

experimental_features: ExperimentalFeatures

Specifies whether self.required_features is allowed to contain experimental features.

memory_hints: MemoryHints

Hints for memory allocation strategies.

trace: Trace

Whether API tracing for debugging is enabled, and where the trace is written if so.

Implementations

Source

impl<L> DeviceDescriptor<L>

pub fn map_label<K>(&self, fun: impl FnOnce(&L) -> K) -> DeviceDescriptor<K>

Takes a closure and maps the label of the device descriptor into another.