#[repr(C)]pub struct ExternalTextureTransferFunction {
pub a: f32,
pub b: f32,
pub g: f32,
pub k: f32,
}Expand description
Parameters describing a gamma encoding transfer function in the form tf = { k * linear | linear < b { a * pow(linear, 1/g) - (a-1) | linear >= b
Fields
a: f32b: f32g: f32k: f32Trait Implementations
Sourceimpl Clone for ExternalTextureTransferFunction
impl Clone for ExternalTextureTransferFunction
Sourcefn clone(&self) -> ExternalTextureTransferFunction
fn clone(&self) -> ExternalTextureTransferFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExternalTextureTransferFunction
impl Default for ExternalTextureTransferFunction
Sourcefn default() -> ExternalTextureTransferFunction
fn default() -> ExternalTextureTransferFunction
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ExternalTextureTransferFunction
impl PartialEq for ExternalTextureTransferFunction
Sourcefn eq(&self, other: &ExternalTextureTransferFunction) -> bool
fn eq(&self, other: &ExternalTextureTransferFunction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ExternalTextureTransferFunction
impl Pod for ExternalTextureTransferFunction
impl StructuralPartialEq for ExternalTextureTransferFunction