pub struct BuildingBlocks {
pub id: PickId,
pub obj_model: Model,
/* private fields */
}Expand description
A collection of identically-shaped building blocks.
Uses GPU instancing to efficiently render many copies of the same model with different transformations. Currently does not perform frustum culling or occlusion culling, so performance may degrade with very large numbers of blocks.
Fields
id: PickIdobj_model: ModelImplementations
Sourceimpl BuildingBlocks
impl BuildingBlocks
pub async fn new( id: impl Into<PickId>, queue: &Queue, device: &Device, start_position: Vector3<f32>, start_rotation: Quaternion<f32>, amount: usize, obj_file: &str, ) -> Self
Sourcepub fn instances_mut(&mut self) -> &mut Vec<Instance>
pub fn instances_mut(&mut self) -> &mut Vec<Instance>
Returns a mutable reference to instances, assumes the instance size changes and recalculates buffers.
If you only mutate some values but don’t intend to change buffer sizes use instances_mut_size_unchanged
pub fn instances_mut_size_unchanged(&mut self) -> &mut [Instance]
pub fn add_instance(&mut self, instance: Instance)
pub fn add_instances(&mut self, instances: Vec<Instance>)
Sourcepub async fn mk_multiple(
queue: &Queue,
device: &Device,
amount: usize,
descr: &[(PickId, &'static str)],
) -> Vec<BuildingBlocks>
pub async fn mk_multiple( queue: &Queue, device: &Device, amount: usize, descr: &[(PickId, &'static str)], ) -> Vec<BuildingBlocks>
This constructor creates amount instances all located at (0.0, 0.0, 0.0).
TODO: pass iter fn to choose the transformation
Sourcepub fn to_clickable(&self, device: &Device, id: PickId) -> Self
pub fn to_clickable(&self, device: &Device, id: PickId) -> Self
This method creates a copy of the original Block (and instances) where only the fragment shader differs. The fragment shader is a U32 id referring to the object that was drawn.
This is used to draw a pick shader which allows identifying objects clicked on with a mouse pointer.
TODO: make this a trait if possible
pub fn clear_first(&mut self, amount: usize, ctx: &Context)
pub fn clear_at(&mut self, from: usize, to: usize, ctx: &Context)
Sourcepub fn to_instanced(&self) -> Instanced<'_>
pub fn to_instanced(&self) -> Instanced<'_>
Returns the inner instanced of the Default render for possible optimizations with Defaults