#[repr(C)]pub enum MipmapFilterMode {
Nearest = 0,
Linear = 1,
}Expand description
Texel mixing mode when sampling between texels.
Corresponds to WebGPU GPUMipmapFilterMode.
Variants
Nearest = 0
Nearest neighbor sampling.
Return the value of the texel nearest to the texture coordinates.
Linear = 1
Linear Interpolation
Select two texels in each dimension and return a linear interpolation between their values.