pub struct Adapter { /* private fields */ }Implementations
Sourceimpl Adapter
impl Adapter
pub fn raw_physical_device(&self) -> PhysicalDevice
pub fn get_physical_device_features(&self) -> &PhysicalDeviceFeatures
pub fn physical_device_capabilities(&self) -> &PhysicalDeviceProperties
pub fn required_device_extensions( &self, features: Features, ) -> Vec<&'static CStr>
Sourcepub fn physical_device_features(
&self,
enabled_extensions: &[&'static CStr],
features: Features,
) -> PhysicalDeviceFeatures
pub fn physical_device_features( &self, enabled_extensions: &[&'static CStr], features: Features, ) -> PhysicalDeviceFeatures
Create a PhysicalDeviceFeatures for opening a logical device with
features from this adapter.
The given enabled_extensions set must include all the extensions
selected by required_device_extensions when passed features.
Otherwise, the PhysicalDeviceFeatures value may not be able to select
all the Vulkan features needed to represent features and this
adapter’s characteristics.
Typically, you’d simply call required_device_extensions, and then pass
its return value and the feature set you gave it directly to this
function. But it’s fine to add more extensions to the list.
Sourcepub unsafe fn device_from_raw(
&self,
raw_device: Device,
drop_callback: Option<Box<dyn FnOnce() + Sync + Send>>,
enabled_extensions: &[&'static CStr],
features: Features,
memory_hints: &MemoryHints,
family_index: u32,
queue_index: u32,
) -> Result<OpenDevice<Api>, DeviceError>
pub unsafe fn device_from_raw( &self, raw_device: Device, drop_callback: Option<Box<dyn FnOnce() + Sync + Send>>, enabled_extensions: &[&'static CStr], features: Features, memory_hints: &MemoryHints, family_index: u32, queue_index: u32, ) -> Result<OpenDevice<Api>, DeviceError>
Safety
raw_devicemust be created from this adapter.raw_devicemust be created usingfamily_index,enabled_extensionsandphysical_device_features()enabled_extensionsmust be a superset ofrequired_device_extensions().- If
drop_callbackisNone, wgpu-hal will take ownership ofraw_device. Ifdrop_callbackisSome,raw_devicemust be valid until the callback is called.
pub fn texture_format_as_raw(&self, texture_format: TextureFormat) -> Format
Sourcepub unsafe fn open_with_callback<'a>(
&self,
features: Features,
memory_hints: &MemoryHints,
callback: Option<Box<dyn for<'arg, 'pnext> FnOnce(CreateDeviceCallbackArgs<'arg, 'pnext, 'a>) + 'a>>,
) -> Result<OpenDevice<Api>, DeviceError>
pub unsafe fn open_with_callback<'a>( &self, features: Features, memory_hints: &MemoryHints, callback: Option<Box<dyn for<'arg, 'pnext> FnOnce(CreateDeviceCallbackArgs<'arg, 'pnext, 'a>) + 'a>>, ) -> Result<OpenDevice<Api>, DeviceError>
Safety:
- Same as
openplus - The callback may not change anything that the device does not support.
- The callback may not remove features.