pub struct AdapterInfo {
pub name: String,
pub vendor: u32,
pub device: u32,
pub device_type: DeviceType,
pub device_pci_bus_id: String,
pub driver: String,
pub driver_info: String,
pub backend: Backend,
pub subgroup_min_size: u32,
pub subgroup_max_size: u32,
pub transient_saves_memory: bool,
}Expand description
Information about an adapter.
Fields
name: StringAdapter name
vendor: u32Backend-specific vendor ID of the adapter
This generally is a 16-bit PCI vendor ID in the least significant bytes of this field. However, more significant bytes may be non-zero if the backend uses a different representation.
- For
Backend::Vulkan, theVkPhysicalDeviceProperties::vendorIDis used, which is a superset of PCI IDs.
device: u32Backend-specific device ID of the adapter
This generally is a 16-bit PCI device ID in the least significant bytes of this field. However, more significant bytes may be non-zero if the backend uses a different representation.
- For
Backend::Vulkan, theVkPhysicalDeviceProperties::deviceIDis used, which is a superset of PCI IDs.
device_type: DeviceTypeType of device
device_pci_bus_id: StringBackend-specific PCI bus ID of the adapter.
- For
Backend::Vulkan,VkPhysicalDevicePCIBusInfoPropertiesEXTis used, if available, in the formbus:device.function, e.g.0000:01:00.0.
driver: StringDriver name
driver_info: StringDriver info
backend: BackendBackend used for device
subgroup_min_size: u32Minimum possible size of a subgroup on this adapter. Will
never be lower than crate::MINIMUM_SUBGROUP_MIN_SIZE.
This will vary from device to device. Typical values are listed below.
- NVIDIA: 32
- AMD GCN/Vega: 64
- AMD RDNA+: 32
- Intel: 8 or 16
- Qualcomm: 64
- WARP: 4
- lavapipe: 8
subgroup_max_size: u32Maximum possible size of a subgroup on this adapter. Will
never be higher than crate::MAXIMUM_SUBGROUP_MAX_SIZE.
This will vary from device to device. Typical values are listed below:
- NVIDIA: 32
- AMD GCN/Vega: 64
- AMD RDNA+: 64
- Intel: 16 or 32
- Qualcomm: 128
- WARP: 4 or 128
- lavapipe: 8
transient_saves_memory: boolIf true, adding [TextureUsages::TRANSIENT] to a texture will decrease memory usage.