pub struct Instance {
pub flags: InstanceFlags,
/* private fields */
}Fields
flags: InstanceFlagsImplementations
Sourceimpl Instance
impl Instance
pub fn new( name: &str, instance_desc: &InstanceDescriptor, telemetry: Option<Telemetry>, ) -> Instance
pub fn raw(&self, backend: Backend) -> Option<&(dyn DynInstance + 'static)>
Sourcepub unsafe fn as_hal<A>(&self) -> Option<&<A as Api>::Instance>where
A: Api,
pub unsafe fn as_hal<A>(&self) -> Option<&<A as Api>::Instance>where
A: Api,
Safety
- The raw instance handle returned must not be manually destroyed.
Sourcepub unsafe fn create_surface(
&self,
display_handle: RawDisplayHandle,
window_handle: RawWindowHandle,
) -> Result<Surface, CreateSurfaceError>
pub unsafe fn create_surface( &self, display_handle: RawDisplayHandle, window_handle: RawWindowHandle, ) -> Result<Surface, CreateSurfaceError>
Creates a new surface targeting the given display/window handles.
Internally attempts to create hal surfaces for all enabled backends.
Fails only if creation for surfaces for all enabled backends fails in which case the error for each enabled backend is listed. Vice versa, if creation for any backend succeeds, success is returned. Surface creation errors are logged to the debug log in any case.
Safety
display_handlemust be a valid object to create a surface upon.window_handlemust remain valid as long as the returnedSurfaceIdis being used.
Sourcepub unsafe fn create_surface_from_drm(
&self,
fd: i32,
plane: u32,
connector_id: u32,
width: u32,
height: u32,
refresh_rate: u32,
) -> Result<Surface, CreateSurfaceError>
pub unsafe fn create_surface_from_drm( &self, fd: i32, plane: u32, connector_id: u32, width: u32, height: u32, refresh_rate: u32, ) -> Result<Surface, CreateSurfaceError>
pub fn enumerate_adapters(&self, backends: Backends) -> Vec<Adapter>
pub fn request_adapter( &self, desc: &RequestAdapterOptions<&Surface>, backends: Backends, ) -> Result<Adapter, RequestAdapterError>